@@ -1,7 +1,7 @@
 #!/bin/sh
-MD5=19891bde93e7233524aa33a30f0a5c25
-BASENAME=libgoto_p4_256p-r0.97
-DESCR="Intel P4, 256k cache, multi-threaded, Linux"
+MD5=09e36584f24bd6e796a62a780fe31b8c
+BASENAME=libgoto_p4_512-r0.94
+DESCR="Intel P4, 512k cache, single-threaded, Linux"
 nb -download http://www.cs.utexas.edu/users/kgoto/libraries/$BASENAME.so.gz $BASENAME.so.gz
 case "`nb -md5 $BASENAME.so.gz | awk '{print $4}'`" in
 	$MD5) ;;
